@@ -80,18 +80,12 @@ public:
     static bool isBusMode(KPublicTransport::Line::Mode mode);
     static bool isBoatMode(KPublicTransport::Line::Mode mode);
 
-    /** Provide a label that represents @p journeySection. */
-    Q_INVOKABLE QString journeySectionLabel(const KPublicTransport::JourneySection &journeySection) const;
-
     /** Create a KPublicTransport::StopoverRequest for the given KItinerary place. */
     Q_INVOKABLE KPublicTransport::StopoverRequest stopoverRequestForPlace(const QVariant &place, const QDateTime &dt) const;
 
     /** Produces a short summary of the given attribution information. */
     Q_INVOKABLE QString attributionSummary(const QVariantList &attributions) const;
 
-    /** Returns @c true when we want to highlight @p sections due to looking problematic. */
-    Q_INVOKABLE bool warnAboutSection(const KPublicTransport::JourneySection &section) const;
-
     /** First public transport section of the given section. */
     static KPublicTransport::JourneySection firstTransportSection(const KPublicTransport::Journey &journey);
     /** Last public transport section of the given section. */
@@ -113,8 +107,8 @@ public:
      */
     [[nodiscard]] static bool isSameStopoverForLayout(const KPublicTransport::Stopover &lhs, const KPublicTransport::Stopover &rhs);
 
-    /** Returns the maximum occupancy found in the given load information set. */
-    Q_INVOKABLE [[nodiscard]] static KPublicTransport::Load::Category maximumOccupancy(const QList<KPublicTransport::LoadInfo> &loadInfo);
+    /** Create a KPublicTransport::Route for a given reservation, for use in journey/trip queries. */
+    [[nodiscard]] static KPublicTransport::Route routeForReservation(const QVariant &res);
 
 private:
     // for use by the template code
@@ -129,7 +123,7 @@ inline T PublicTransport::placeFromLocation(const KPublicTransport::Location &lo
     T place;
     place.setName(loc.name());
     if (loc.hasCoordinate()) {
-        place.setGeo(KItinerary::GeoCoordinates{(float)loc.latitude(), (float)loc.longitude()});
+        place.setGeo(KItinerary::GeoCoordinates{loc.latitude(), loc.longitude()});
     }
     place.setIdentifier(idenfitierFromLocation(loc));
     place.setAddress(addressFromLocation(loc));
